@@ -1,5 +1,3 @@
-import numpy as np
-from rdkit.Chem import GetDistanceMatrix
 from reinvent_scoring.scoring.component_parameters import ComponentParameters
 from reinvent_scoring.scoring.score_components.physchem.base_physchem_component import BasePhysChemComponent
 
@@ -9,4 +7,4 @@ class GraphLength(BasePhysChemComponent):
         super().__init__(parameters)
 
     def _calculate_phys_chem_property(self, mol):
-        return(int(np.max(GetDistanceMatrix(mol))))
+        return self._phys_chem_descriptors.maximum_graph_length(mol)
