@@ -12,7 +12,7 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     NumberOfStereoCenters, \
     LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, LinkerNumRings, LinkerNumAliphaticRings, \
     LinkerNumAromaticRings, LinkerNumSPAtoms, LinkerNumSP2Atoms, LinkerNumSP3Atoms, LinkerNumHBA, \
-    LinkerNumHBD, LinkerMolWeight, DockStream, BuildingBlockAvailabilityComponent, \
+    LinkerNumHBD, LinkerMolWeight, LinkerRatioRotatableBonds, DockStream, BuildingBlockAvailabilityComponent, \
     NumAromaticRings, NumAliphaticRings
 from reinvent_scoring.scoring.score_components.console_invoked import AZgard
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
@@ -81,6 +81,7 @@ class ScoreComponentFactory:
             enum.LINKER_NUM_HBA: LinkerNumHBA,
             enum.LINKER_NUM_HBD: LinkerNumHBD,
             enum.LINKER_MOL_WEIGHT: LinkerMolWeight,
+            enum.LINKER_RATIO_ROTATABLE_BONDS: LinkerRatioRotatableBonds,
             enum.DOCKSTREAM: DockStream,
             enum.AZGARD: AZgard,
             enum.AIZYNTH: BuildingBlockAvailabilityComponent
